@@ -15,13 +15,6 @@ from .protocols import (
     SUBSTATE
 )
 
-# Import protocol implementations
-from .protocols.redis_protocol import RedisProtocol
-from .protocols.websocket_protocol import WebSocketProtocol
-from .protocols.zeromq_protocol import ZeroMQProtocol
-from .protocols.mqtt_protocol import MQTTProtocol
-
-
 class ProtocolFactory:
     """Factory for creating protocol instances"""
     
@@ -30,22 +23,42 @@ class ProtocolFactory:
         """Create appropriate protocol instance based on config"""
         
         if config.protocol_type == ProtocolType.MQTT:
-            return MQTTProtocol(config)
+            try:
+                from .protocols.mqtt_protocol import MQTTProtocol
+                return MQTTProtocol(config)
+            except ImportError as e:
+                raise ImportError(f"MQTT dependencies not found. Install with: pip install aethermagic[mqtt]. Error: {e}")
             
         elif config.protocol_type == ProtocolType.REDIS:
-            return RedisProtocol(config)
+            try:
+                from .protocols.redis_protocol import RedisProtocol
+                return RedisProtocol(config)
+            except ImportError as e:
+                raise ImportError(f"Redis dependencies not found. Install with: pip install aethermagic[redis]. Error: {e}")
                 
         elif config.protocol_type == ProtocolType.HTTP:
-            mode = config.extra_params.get('mode', 'client')
-            return WebSocketProtocol(config, mode)
+            try:
+                from .protocols.websocket_protocol import WebSocketProtocol
+                mode = config.extra_params.get('mode', 'client')
+                return WebSocketProtocol(config, mode)
+            except ImportError as e:
+                raise ImportError(f"WebSocket dependencies not found. Install with: pip install aethermagic[websocket]. Error: {e}")
             
         elif config.protocol_type == ProtocolType.WEBSOCKET:
-            mode = config.extra_params.get('mode', 'client')  
-            return WebSocketProtocol(config, mode)
+            try:
+                from .protocols.websocket_protocol import WebSocketProtocol
+                mode = config.extra_params.get('mode', 'client')  
+                return WebSocketProtocol(config, mode)
+            except ImportError as e:
+                raise ImportError(f"WebSocket dependencies not found. Install with: pip install aethermagic[websocket]. Error: {e}")
             
         elif config.protocol_type == ProtocolType.ZEROMQ:
-            pattern = config.extra_params.get('pattern', 'pubsub')
-            return ZeroMQProtocol(config, pattern)
+            try:
+                from .protocols.zeromq_protocol import ZeroMQProtocol
+                pattern = config.extra_params.get('pattern', 'pubsub')
+                return ZeroMQProtocol(config, pattern)
+            except ImportError as e:
+                raise ImportError(f"ZeroMQ dependencies not found. Install with: pip install aethermagic[zeromq]. Error: {e}")
             
         else:
             raise ValueError(f"Unsupported protocol: {config.protocol_type}")
@@ -380,7 +393,8 @@ class MultiProtocolAetherMagic:
             listener['context'],
             tid_for_subscription,  # Use '+' for perform subscriptions
             listener['action'],
-            shared=use_shared  # Enable shared subscriptions for task distribution
+            shared=use_shared,  # Enable shared subscriptions for task distribution
+            workgroup=listener.get('workgroup', 'default')  # Add workgroup for shared subscriptions
         )
     
     def __data_to_fulldata(self, action, status, progress, data):
@@ -504,17 +518,14 @@ class MultiProtocolAetherMagic:
     
     async def __send_immediate(self, job, workgroup, task, context, action, tid, payload, retain=False):
         """Send message immediately"""
-        print(f"🔥 DEBUG: __send_immediate called - connected={self.__connected}")
         if self.__connected:
             try:
                 topic = self.protocol.generate_topic(job, task, context, tid, action)
-                print(f"🔥 DEBUG: Generated topic={topic}")
                 
                 # Parse payload to create AetherMessage
                 payload_data = json.loads(payload)
                 message = AetherMessage.from_dict(payload_data)
                 
-                print(f"🔥 DEBUG: Calling protocol.publish")
                 await self.protocol.publish(topic, message, retain)
                 await asyncio.sleep(0.001)  # Brief yield
                 
@@ -589,16 +600,16 @@ class MultiProtocolAetherMagic:
     
     # New methods for load balancing support
     async def perform_task(self, job: str, task: str, context: str, data: dict, 
-                          shared: bool = False, immediate: bool = False):
+                          shared: bool = False, workgroup: str = "default", immediate: bool = False):
         """Perform task with optional load balancing"""
         tid = f"task_{id(data)}"
         payload = self.__data_to_payload('perform', 'initialized', 0, data)
         
         if shared:
             # Use shared subscription approach for load balancing
-            await self.__send_shared(job, task, context, 'perform', tid, payload, retain=False, immediate=immediate)
+            await self.__send_shared(job, task, context, 'perform', tid, payload, workgroup=workgroup, retain=False, immediate=immediate)
         else:
-            await self.__send(job, "default", task, context, 'perform', tid, payload, retain=False, immediate=immediate)
+            await self.__send(job, workgroup, task, context, 'perform', tid, payload, retain=False, immediate=immediate)
     
     async def add_task(self, job: str, task: str, context: str, callback, shared: bool = False):
         """Add task handler with optional load balancing"""
@@ -610,13 +621,17 @@ class MultiProtocolAetherMagic:
             await self.subscribe(job, "default", task, context, tid, 'perform', callback)
     
     async def __send_shared(self, job: str, task: str, context: str, action: str, 
-                           tid: str, payload: dict, retain: bool = False, immediate: bool = False):
+                           tid: str, payload: dict, workgroup: str = "default", retain: bool = False, immediate: bool = False):
         """Send message using shared subscription for load balancing"""
-        topic = self.protocol.generate_topic(job, task, context, tid, action, shared=True)
+        # ОТПРАВКА ВСЕГДА В ОБЫЧНЫЙ ТОПИК! Shared работает только при подписке
+        topic = self.protocol.generate_topic(job, task, context, tid, action, shared=False)
         message = AetherMessage(
             action=action,
+            status='initialized',
+            progress=0,
             data=payload,
-            source=self.client_id
+            host=self.__hostname,
+            client=self.__identifier
         )
         
         if immediate or self.__connected:
@@ -655,7 +670,7 @@ class AetherMagic(MultiProtocolAetherMagic):
     """
     
     def __init__(self, server=None, port=None, ssl=None, user=None, password=None, union=None, 
-                 protocol_type=None, host=None, channel=None, **kwargs):
+                 protocol_type=None, protocol=None, host=None, channel=None, **kwargs):
         
         # Old initialization style (MQTT only) - highest priority
         if server is not None:
@@ -685,6 +700,35 @@ class AetherMagic(MultiProtocolAetherMagic):
                 **kwargs
             )
         
+        # String protocol parameter (e.g., protocol="redis")
+        elif protocol is not None:
+            try:
+                proto_type = ProtocolType(protocol.lower())
+            except ValueError:
+                raise ValueError(f"Unsupported protocol: {protocol}")
+            
+            # Set default ports based on protocol
+            default_ports = {
+                ProtocolType.MQTT: 1883,
+                ProtocolType.REDIS: 6379,
+                ProtocolType.HTTP: 80,
+                ProtocolType.WEBSOCKET: 8080,
+                ProtocolType.ZEROMQ: 5555,
+                ProtocolType.RABBITMQ: 5672
+            }
+            
+            super().__init__(
+                protocol_type=proto_type,
+                host=host or 'localhost',
+                port=port or default_ports.get(proto_type, 1883),
+                ssl=ssl or False,
+                username=user or '',
+                password=password or '',
+                union=union or 'default',
+                channel=channel or '',
+                **kwargs
+            )
+        
         # Default to MQTT for full backward compatibility
         else:
             super().__init__(
